PROTOCOL_VERSION = 14
RELAY_BLOCK_CAN_SEND_TXS_MESSAGE = 12
RELAY_BLOCK_CAN_SEND_COMPRESSED_BLOCK_TXS_MESSAGE = 13

# PROTOCOL VERSION 14 (6/9/2020)
# Pong(Ping Response contains additional timestamp)

# PROTOCOL_VERSION 12 (06/08/2020)
# relay block can send txs_message to gateways
# PROTOCOL_VERSION 11 (7/17/2020)
# add memory utilization to BDN performance stats message
#
# PROTOCOL_VERSION 10 (6/8/2020)
# change maximum transaction count in BDN performance stats message
#
# PROTOCOL_VERSION 9 (4/17/2020)
# add broadcast_type to broadcast messages
#
# PROTOCOL_VERSION 8 (2/5/2020)
# add timestamp to tx message types
#
# PROTOCOL_VERSION 7
# added TxQuotaFlag to transaction messages
